# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="create_or_update_document_property_online_response.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

class CreateOrUpdateDocumentPropertyOnlineResponse(object):
    """
    Response model for create_or_update_document_property_online operation.
    Initializes a new instance.
    """
    def __init__(self, model, document):
        self.model = model
        self.document = document


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="structured_document_tag.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class StructuredDocumentTag(object):
    """DTO container with a StructuredDocumentTag.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'node_id': 'str',
        'list_items': 'list[StructuredDocumentTagListItem]',
        'checked': 'bool',
        'appearance': 'str',
        'date_display_locale': 'int',
        'date_display_format': 'str',
        'full_date': 'datetime',
        'title': 'str',
        'date_storage_format': 'str',
        'building_block_gallery': 'str',
        'building_block_category': 'str',
        'multiline': 'bool',
        'color': 'XmlColor',
        'style_name': 'str',
        'calendar_type': 'str',
        'is_temporary': 'bool',
        'placeholder_name': 'str',
        'lock_content_control': 'bool',
        'lock_contents': 'bool',
        'is_showing_placeholder_text': 'bool',
        'tag': 'str',
        'id': 'int',
        'word_open_xml': 'str',
        'level': 'str',
        'sdt_type': 'str'
    }

    attribute_map = {
        'link': 'Link',
        'node_id': 'NodeId',
        'list_items': 'ListItems',
        'checked': 'Checked',
        'appearance': 'Appearance',
        'date_display_locale': 'DateDisplayLocale',
        'date_display_format': 'DateDisplayFormat',
        'full_date': 'FullDate',
        'title': 'Title',
        'date_storage_format': 'DateStorageFormat',
        'building_block_gallery': 'BuildingBlockGallery',
        'building_block_category': 'BuildingBlockCategory',
        'multiline': 'Multiline',
        'color': 'Color',
        'style_name': 'StyleName',
        'calendar_type': 'CalendarType',
        'is_temporary': 'IsTemporary',
        'placeholder_name': 'PlaceholderName',
        'lock_content_control': 'LockContentControl',
        'lock_contents': 'LockContents',
        'is_showing_placeholder_text': 'IsShowingPlaceholderText',
        'tag': 'Tag',
        'id': 'Id',
        'word_open_xml': 'WordOpenXML',
        'level': 'Level',
        'sdt_type': 'SdtType'
    }

    def __init__(self, link=None, node_id=None, list_items=None, checked=None, appearance=None, date_display_locale=None, date_display_format=None, full_date=None, title=None, date_storage_format=None, building_block_gallery=None, building_block_category=None, multiline=None, color=None, style_name=None, calendar_type=None, is_temporary=None, placeholder_name=None, lock_content_control=None, lock_contents=None, is_showing_placeholder_text=None, tag=None, id=None, level=None, sdt_type=None):  # noqa: E501
        """StructuredDocumentTag - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._node_id = None
        self._list_items = None
        self._checked = None
        self._appearance = None
        self._date_display_locale = None
        self._date_display_format = None
        self._full_date = None
        self._title = None
        self._date_storage_format = None
        self._building_block_gallery = None
        self._building_block_category = None
        self._multiline = None
        self._color = None
        self._style_name = None
        self._calendar_type = None
        self._is_temporary = None
        self._placeholder_name = None
        self._lock_content_control = None
        self._lock_contents = None
        self._is_showing_placeholder_text = None
        self._tag = None
        self._id = None
        self._word_open_xml = None
        self._level = None
        self._sdt_type = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if node_id is not None:
            self.node_id = node_id
        if list_items is not None:
            self.list_items = list_items
        if checked is not None:
            self.checked = checked
        if appearance is not None:
            self.appearance = appearance
        if date_display_locale is not None:
            self.date_display_locale = date_display_locale
        if date_display_format is not None:
            self.date_display_format = date_display_format
        if full_date is not None:
            self.full_date = full_date
        if title is not None:
            self.title = title
        if date_storage_format is not None:
            self.date_storage_format = date_storage_format
        if building_block_gallery is not None:
            self.building_block_gallery = building_block_gallery
        if building_block_category is not None:
            self.building_block_category = building_block_category
        if multiline is not None:
            self.multiline = multiline
        if color is not None:
            self.color = color
        if style_name is not None:
            self.style_name = style_name
        if calendar_type is not None:
            self.calendar_type = calendar_type
        if is_temporary is not None:
            self.is_temporary = is_temporary
        if placeholder_name is not None:
            self.placeholder_name = placeholder_name
        if lock_content_control is not None:
            self.lock_content_control = lock_content_control
        if lock_contents is not None:
            self.lock_contents = lock_contents
        if is_showing_placeholder_text is not None:
            self.is_showing_placeholder_text = is_showing_placeholder_text
        if tag is not None:
            self.tag = tag
        if id is not None:
            self.id = id
        if level is not None:
            self.level = level
        if sdt_type is not None:
            self.sdt_type = sdt_type

    @property
    def link(self):
        """Gets the link of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this StructuredDocumentTag.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this StructuredDocumentTag.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this StructuredDocumentTag.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def node_id(self):
        """Gets the node_id of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the node id.  # noqa: E501

        :return: The node_id of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this StructuredDocumentTag.

        Gets or sets the node id.  # noqa: E501

        :param node_id: The node_id of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        self._node_id = node_id

    @property
    def list_items(self):
        """Gets the list_items of this StructuredDocumentTag.  # noqa: E501

        Gets or sets Aspose.Words.Markup.SdtListItemCollection associated with this SDT. Accessing this property will only work for Aspose.Words.Markup.SdtType.ComboBox or Aspose.Words.Markup.SdtType.DropDownList SDT types. For all other SDT types exception will occur.  # noqa: E501

        :return: The list_items of this StructuredDocumentTag.  # noqa: E501
        :rtype: list[StructuredDocumentTagListItem]
        """
        return self._list_items

    @list_items.setter
    def list_items(self, list_items):
        """Sets the list_items of this StructuredDocumentTag.

        Gets or sets Aspose.Words.Markup.SdtListItemCollection associated with this SDT. Accessing this property will only work for Aspose.Words.Markup.SdtType.ComboBox or Aspose.Words.Markup.SdtType.DropDownList SDT types. For all other SDT types exception will occur.  # noqa: E501

        :param list_items: The list_items of this StructuredDocumentTag.  # noqa: E501
        :type: list[StructuredDocumentTagListItem]
        """
        self._list_items = list_items

    @property
    def checked(self):
        """Gets the checked of this StructuredDocumentTag.  # noqa: E501

        Gets or sets a value indicating whether current state of the Checkbox SDT. Default value for this property. Accessing this property will only work for Aspose.Words.Markup.SdtType.Checkbox SDT types. For all other SDT types exception will occur.  # noqa: E501

        :return: The checked of this StructuredDocumentTag.  # noqa: E501
        :rtype: bool
        """
        return self._checked

    @checked.setter
    def checked(self, checked):
        """Sets the checked of this StructuredDocumentTag.

        Gets or sets a value indicating whether current state of the Checkbox SDT. Default value for this property. Accessing this property will only work for Aspose.Words.Markup.SdtType.Checkbox SDT types. For all other SDT types exception will occur.  # noqa: E501

        :param checked: The checked of this StructuredDocumentTag.  # noqa: E501
        :type: bool
        """
        self._checked = checked

    @property
    def appearance(self):
        """Gets the appearance of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the appearance of a structured document tag.  # noqa: E501

        :return: The appearance of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._appearance

    @appearance.setter
    def appearance(self, appearance):
        """Sets the appearance of this StructuredDocumentTag.

        Gets or sets the appearance of a structured document tag.  # noqa: E501

        :param appearance: The appearance of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        allowed_values = ["BoundingBox", "Default", "Tags", "Hidden"]  # noqa: E501
        if not appearance.isdigit():
            if appearance not in allowed_values:
                raise ValueError(
                    "Invalid value for `appearance` ({0}), must be one of {1}"  # noqa: E501
                    .format(appearance, allowed_values))
            self._appearance = appearance
        else:
            self._appearance = allowed_values[int(appearance) if six.PY3 else long(appearance)]

    @property
    def date_display_locale(self):
        """Gets the date_display_locale of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the language format for the date displayed in this SDT. Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :return: The date_display_locale of this StructuredDocumentTag.  # noqa: E501
        :rtype: int
        """
        return self._date_display_locale

    @date_display_locale.setter
    def date_display_locale(self, date_display_locale):
        """Sets the date_display_locale of this StructuredDocumentTag.

        Gets or sets the language format for the date displayed in this SDT. Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :param date_display_locale: The date_display_locale of this StructuredDocumentTag.  # noqa: E501
        :type: int
        """
        self._date_display_locale = date_display_locale

    @property
    def date_display_format(self):
        """Gets the date_display_format of this StructuredDocumentTag.  # noqa: E501

        Gets or sets String that represents the format in which dates are displayed. Can not be null. The dates for English (U.S.) is "mm/dd/yyyy". Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :return: The date_display_format of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._date_display_format

    @date_display_format.setter
    def date_display_format(self, date_display_format):
        """Sets the date_display_format of this StructuredDocumentTag.

        Gets or sets String that represents the format in which dates are displayed. Can not be null. The dates for English (U.S.) is "mm/dd/yyyy". Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :param date_display_format: The date_display_format of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        self._date_display_format = date_display_format

    @property
    def full_date(self):
        """Gets the full_date of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the full date and time last entered into this SDT. Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :return: The full_date of this StructuredDocumentTag.  # noqa: E501
        :rtype: datetime
        """
        return self._full_date

    @full_date.setter
    def full_date(self, full_date):
        """Sets the full_date of this StructuredDocumentTag.

        Gets or sets the full date and time last entered into this SDT. Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :param full_date: The full_date of this StructuredDocumentTag.  # noqa: E501
        :type: datetime
        """
        self._full_date = full_date

    @property
    def title(self):
        """Gets the title of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the friendly name associated with this SDT. Can not be null.  # noqa: E501

        :return: The title of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this StructuredDocumentTag.

        Gets or sets the friendly name associated with this SDT. Can not be null.  # noqa: E501

        :param title: The title of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        self._title = title

    @property
    def date_storage_format(self):
        """Gets the date_storage_format of this StructuredDocumentTag.  # noqa: E501

        Gets or sets format in which the date for a date SDT is stored when the SDT is bound to an XML node in the document's data store. Default value is Aspose.Words.Markup.SdtDateStorageFormat.DateTime. Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :return: The date_storage_format of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._date_storage_format

    @date_storage_format.setter
    def date_storage_format(self, date_storage_format):
        """Sets the date_storage_format of this StructuredDocumentTag.

        Gets or sets format in which the date for a date SDT is stored when the SDT is bound to an XML node in the document's data store. Default value is Aspose.Words.Markup.SdtDateStorageFormat.DateTime. Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :param date_storage_format: The date_storage_format of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        allowed_values = ["Date", "DateTime", "Default", "Text"]  # noqa: E501
        if not date_storage_format.isdigit():
            if date_storage_format not in allowed_values:
                raise ValueError(
                    "Invalid value for `date_storage_format` ({0}), must be one of {1}"  # noqa: E501
                    .format(date_storage_format, allowed_values))
            self._date_storage_format = date_storage_format
        else:
            self._date_storage_format = allowed_values[int(date_storage_format) if six.PY3 else long(date_storage_format)]

    @property
    def building_block_gallery(self):
        """Gets the building_block_gallery of this StructuredDocumentTag.  # noqa: E501

        Gets or sets type of building block for this SDT. Can not be null. Accessing this property will only work for Aspose.Words.Markup.SdtType.BuildingBlockGallery and Aspose.Words.Markup.SdtType.DocPartObj SDT types. It is read-only for SDT of the document part type. For all other SDT types exception will occur.  # noqa: E501

        :return: The building_block_gallery of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._building_block_gallery

    @building_block_gallery.setter
    def building_block_gallery(self, building_block_gallery):
        """Sets the building_block_gallery of this StructuredDocumentTag.

        Gets or sets type of building block for this SDT. Can not be null. Accessing this property will only work for Aspose.Words.Markup.SdtType.BuildingBlockGallery and Aspose.Words.Markup.SdtType.DocPartObj SDT types. It is read-only for SDT of the document part type. For all other SDT types exception will occur.  # noqa: E501

        :param building_block_gallery: The building_block_gallery of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        self._building_block_gallery = building_block_gallery

    @property
    def building_block_category(self):
        """Gets the building_block_category of this StructuredDocumentTag.  # noqa: E501

        Gets or sets category of building block for this SDT node. Can not be null. Accessing this property will only work for Aspose.Words.Markup.SdtType.BuildingBlockGallery and Aspose.Words.Markup.SdtType.DocPartObj SDT types. It is read-only for SDT of the document part type. For all other SDT types exception will occur.  # noqa: E501

        :return: The building_block_category of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._building_block_category

    @building_block_category.setter
    def building_block_category(self, building_block_category):
        """Sets the building_block_category of this StructuredDocumentTag.

        Gets or sets category of building block for this SDT node. Can not be null. Accessing this property will only work for Aspose.Words.Markup.SdtType.BuildingBlockGallery and Aspose.Words.Markup.SdtType.DocPartObj SDT types. It is read-only for SDT of the document part type. For all other SDT types exception will occur.  # noqa: E501

        :param building_block_category: The building_block_category of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        self._building_block_category = building_block_category

    @property
    def multiline(self):
        """Gets the multiline of this StructuredDocumentTag.  # noqa: E501

        Gets or sets a value indicating whether this SDT allows multiple lines of text. Accessing this property will only work for Aspose.Words.Markup.SdtType.RichText and Aspose.Words.Markup.SdtType.PlainText SDT type. For all other SDT types exception will occur.  # noqa: E501

        :return: The multiline of this StructuredDocumentTag.  # noqa: E501
        :rtype: bool
        """
        return self._multiline

    @multiline.setter
    def multiline(self, multiline):
        """Sets the multiline of this StructuredDocumentTag.

        Gets or sets a value indicating whether this SDT allows multiple lines of text. Accessing this property will only work for Aspose.Words.Markup.SdtType.RichText and Aspose.Words.Markup.SdtType.PlainText SDT type. For all other SDT types exception will occur.  # noqa: E501

        :param multiline: The multiline of this StructuredDocumentTag.  # noqa: E501
        :type: bool
        """
        self._multiline = multiline

    @property
    def color(self):
        """Gets the color of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the color of the structured document tag.  # noqa: E501

        :return: The color of this StructuredDocumentTag.  # noqa: E501
        :rtype: XmlColor
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this StructuredDocumentTag.

        Gets or sets the color of the structured document tag.  # noqa: E501

        :param color: The color of this StructuredDocumentTag.  # noqa: E501
        :type: XmlColor
        """
        self._color = color

    @property
    def style_name(self):
        """Gets the style_name of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the name of the style applied to the structured document tag.  # noqa: E501

        :return: The style_name of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._style_name

    @style_name.setter
    def style_name(self, style_name):
        """Sets the style_name of this StructuredDocumentTag.

        Gets or sets the name of the style applied to the structured document tag.  # noqa: E501

        :param style_name: The style_name of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        self._style_name = style_name

    @property
    def calendar_type(self):
        """Gets the calendar_type of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the type of calendar for this SDT. Default is Aspose.Words.Markup.SdtCalendarType.Default. Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :return: The calendar_type of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._calendar_type

    @calendar_type.setter
    def calendar_type(self, calendar_type):
        """Sets the calendar_type of this StructuredDocumentTag.

        Gets or sets the type of calendar for this SDT. Default is Aspose.Words.Markup.SdtCalendarType.Default. Accessing this property will only work for Aspose.Words.Markup.SdtType.Date SDT type. For all other SDT types exception will occur.  # noqa: E501

        :param calendar_type: The calendar_type of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        allowed_values = ["Default", "Gregorian", "GregorianArabic", "GregorianMeFrench", "GregorianUs", "GregorianXlitEnglish", "GregorianXlitFrench", "Hebrew", "Hijri", "Japan", "Korea", "None", "Saka", "Taiwan", "Thai"]  # noqa: E501
        if not calendar_type.isdigit():
            if calendar_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `calendar_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(calendar_type, allowed_values))
            self._calendar_type = calendar_type
        else:
            self._calendar_type = allowed_values[int(calendar_type) if six.PY3 else long(calendar_type)]

    @property
    def is_temporary(self):
        """Gets the is_temporary of this StructuredDocumentTag.  # noqa: E501

        Gets or sets a value indicating whether this SDT shall be removed from the WordProcessingML document when its contents are modified.  # noqa: E501

        :return: The is_temporary of this StructuredDocumentTag.  # noqa: E501
        :rtype: bool
        """
        return self._is_temporary

    @is_temporary.setter
    def is_temporary(self, is_temporary):
        """Sets the is_temporary of this StructuredDocumentTag.

        Gets or sets a value indicating whether this SDT shall be removed from the WordProcessingML document when its contents are modified.  # noqa: E501

        :param is_temporary: The is_temporary of this StructuredDocumentTag.  # noqa: E501
        :type: bool
        """
        self._is_temporary = is_temporary

    @property
    def placeholder_name(self):
        """Gets the placeholder_name of this StructuredDocumentTag.  # noqa: E501

        Gets or sets Name of the Aspose.Words.BuildingBlocks.BuildingBlock containing placeholder text. Aspose.Words.BuildingBlocks.BuildingBlock with this name Aspose.Words.BuildingBlocks.BuildingBlock.Name has to be present in the Aspose.Words.Document.GlossaryDocument otherwise System.InvalidOperationException will occur.  # noqa: E501

        :return: The placeholder_name of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._placeholder_name

    @placeholder_name.setter
    def placeholder_name(self, placeholder_name):
        """Sets the placeholder_name of this StructuredDocumentTag.

        Gets or sets Name of the Aspose.Words.BuildingBlocks.BuildingBlock containing placeholder text. Aspose.Words.BuildingBlocks.BuildingBlock with this name Aspose.Words.BuildingBlocks.BuildingBlock.Name has to be present in the Aspose.Words.Document.GlossaryDocument otherwise System.InvalidOperationException will occur.  # noqa: E501

        :param placeholder_name: The placeholder_name of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        self._placeholder_name = placeholder_name

    @property
    def lock_content_control(self):
        """Gets the lock_content_control of this StructuredDocumentTag.  # noqa: E501

        Gets or sets a value indicating whether, this property will prohibit a user from deleting this SDT.  # noqa: E501

        :return: The lock_content_control of this StructuredDocumentTag.  # noqa: E501
        :rtype: bool
        """
        return self._lock_content_control

    @lock_content_control.setter
    def lock_content_control(self, lock_content_control):
        """Sets the lock_content_control of this StructuredDocumentTag.

        Gets or sets a value indicating whether, this property will prohibit a user from deleting this SDT.  # noqa: E501

        :param lock_content_control: The lock_content_control of this StructuredDocumentTag.  # noqa: E501
        :type: bool
        """
        self._lock_content_control = lock_content_control

    @property
    def lock_contents(self):
        """Gets the lock_contents of this StructuredDocumentTag.  # noqa: E501

        Gets or sets a value indicating whether, this property will prohibit a user from editing the contents of this SDT.  # noqa: E501

        :return: The lock_contents of this StructuredDocumentTag.  # noqa: E501
        :rtype: bool
        """
        return self._lock_contents

    @lock_contents.setter
    def lock_contents(self, lock_contents):
        """Sets the lock_contents of this StructuredDocumentTag.

        Gets or sets a value indicating whether, this property will prohibit a user from editing the contents of this SDT.  # noqa: E501

        :param lock_contents: The lock_contents of this StructuredDocumentTag.  # noqa: E501
        :type: bool
        """
        self._lock_contents = lock_contents

    @property
    def is_showing_placeholder_text(self):
        """Gets the is_showing_placeholder_text of this StructuredDocumentTag.  # noqa: E501

        Gets or sets a value indicating whether the content of this SDT shall be interpreted to contain placeholder text (as opposed to regular text contents within the SDT). If set to true, this state shall be resumed (showing placeholder text) upon opening his document.  # noqa: E501

        :return: The is_showing_placeholder_text of this StructuredDocumentTag.  # noqa: E501
        :rtype: bool
        """
        return self._is_showing_placeholder_text

    @is_showing_placeholder_text.setter
    def is_showing_placeholder_text(self, is_showing_placeholder_text):
        """Sets the is_showing_placeholder_text of this StructuredDocumentTag.

        Gets or sets a value indicating whether the content of this SDT shall be interpreted to contain placeholder text (as opposed to regular text contents within the SDT). If set to true, this state shall be resumed (showing placeholder text) upon opening his document.  # noqa: E501

        :param is_showing_placeholder_text: The is_showing_placeholder_text of this StructuredDocumentTag.  # noqa: E501
        :type: bool
        """
        self._is_showing_placeholder_text = is_showing_placeholder_text

    @property
    def tag(self):
        """Gets the tag of this StructuredDocumentTag.  # noqa: E501

        Gets or sets a tag associated with the current SDT node. Can not be null. A tag is an arbitrary string which applications can associate with SDT in order to identify it without providing a visible friendly name.  # noqa: E501

        :return: The tag of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this StructuredDocumentTag.

        Gets or sets a tag associated with the current SDT node. Can not be null. A tag is an arbitrary string which applications can associate with SDT in order to identify it without providing a visible friendly name.  # noqa: E501

        :param tag: The tag of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        self._tag = tag

    @property
    def id(self):
        """Gets the id of this StructuredDocumentTag.  # noqa: E501

        Gets or sets a unique read-only persistent numerical Id for this SDT. Id attribute shall follow these rules: - The document shall retain SDT ids only if the whole document is cloned Aspose.Words.Document.Clone. - During Aspose.Words.DocumentBase.ImportNode(Aspose.Words.Node,System.Boolean) - Id shall be retained if import does not cause conflicts with other SDT Ids in the target document. - If multiple SDT nodes specify the same decimal number value for the Id attribute, then the first SDT in the document shall maintain this original Id, and all subsequent - SDT nodes shall have new identifiers assigned to them when the document is loaded. - During standalone SDT Aspose.Words.Markup.StructuredDocumentTag.Clone(System.Boolean,Aspose.Words.INodeCloningListener) operation new unique ID will be generated for the cloned SDT node. - If Id is not specified in the source document, then the SDT node shall have a new unique identifier assigned to it when the document is loaded.  # noqa: E501

        :return: The id of this StructuredDocumentTag.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StructuredDocumentTag.

        Gets or sets a unique read-only persistent numerical Id for this SDT. Id attribute shall follow these rules: - The document shall retain SDT ids only if the whole document is cloned Aspose.Words.Document.Clone. - During Aspose.Words.DocumentBase.ImportNode(Aspose.Words.Node,System.Boolean) - Id shall be retained if import does not cause conflicts with other SDT Ids in the target document. - If multiple SDT nodes specify the same decimal number value for the Id attribute, then the first SDT in the document shall maintain this original Id, and all subsequent - SDT nodes shall have new identifiers assigned to them when the document is loaded. - During standalone SDT Aspose.Words.Markup.StructuredDocumentTag.Clone(System.Boolean,Aspose.Words.INodeCloningListener) operation new unique ID will be generated for the cloned SDT node. - If Id is not specified in the source document, then the SDT node shall have a new unique identifier assigned to it when the document is loaded.  # noqa: E501

        :param id: The id of this StructuredDocumentTag.  # noqa: E501
        :type: int
        """
        self._id = id

    @property
    def word_open_xml(self):
        """Gets the word_open_xml of this StructuredDocumentTag.  # noqa: E501

        Gets a string that represents the XML contained within the node in the Aspose.Words.SaveFormat.FlatOpc format.  # noqa: E501

        :return: The word_open_xml of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._word_open_xml


    @property
    def level(self):
        """Gets the level of this StructuredDocumentTag.  # noqa: E501

        Gets or sets the level at which this SDT occurs in the document tree.  # noqa: E501

        :return: The level of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this StructuredDocumentTag.

        Gets or sets the level at which this SDT occurs in the document tree.  # noqa: E501

        :param level: The level of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        allowed_values = ["Unknown", "Inline", "Block", "Row", "Cell"]  # noqa: E501
        if not level.isdigit():
            if level not in allowed_values:
                raise ValueError(
                    "Invalid value for `level` ({0}), must be one of {1}"  # noqa: E501
                    .format(level, allowed_values))
            self._level = level
        else:
            self._level = allowed_values[int(level) if six.PY3 else long(level)]

    @property
    def sdt_type(self):
        """Gets the sdt_type of this StructuredDocumentTag.  # noqa: E501

        Gets or sets type of this Structured document tag.  # noqa: E501

        :return: The sdt_type of this StructuredDocumentTag.  # noqa: E501
        :rtype: str
        """
        return self._sdt_type

    @sdt_type.setter
    def sdt_type(self, sdt_type):
        """Sets the sdt_type of this StructuredDocumentTag.

        Gets or sets type of this Structured document tag.  # noqa: E501

        :param sdt_type: The sdt_type of this StructuredDocumentTag.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Bibliography", "Citation", "Equation", "DropDownList", "ComboBox", "Date", "BuildingBlockGallery", "DocPartObj", "Group", "Picture", "RichText", "PlainText", "Checkbox", "RepeatingSection", "RepeatingSectionItem", "EntityPicker"]  # noqa: E501
        if not sdt_type.isdigit():
            if sdt_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `sdt_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(sdt_type, allowed_values))
            self._sdt_type = sdt_type
        else:
            self._sdt_type = allowed_values[int(sdt_type) if six.PY3 else long(sdt_type)]


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

        if self._link is not None:
            self._link.validate()




        if self._list_items is not None:
            for elementListItems in self._list_items:
                if elementListItems is not None:
                    elementListItems.validate()













        if self._color is not None:
            self._color.validate()














    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StructuredDocumentTag):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="get_table_cell_online_request.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import json

from six.moves.urllib.parse import quote
from asposewordscloud import *
from asposewordscloud.models import *
from asposewordscloud.models.requests import *
from asposewordscloud.models.responses import *

class GetTableCellOnlineRequest(BaseRequestObject):
    """
    Request model for get_table_cell_online operation.
    Initializes a new instance.
    :param document The document.
    :param table_row_path The path to the table row in the document tree.
    :param index Object index.
    :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
    :param password Password of protected Word document. Use the parameter to pass a password via SDK. SDK encrypts it automatically. We don't recommend to use the parameter to pass a plain password for direct call of API.
    :param encrypted_password Password of protected Word document. Use the parameter to pass an encrypted password for direct calls of API. See SDK code for encyption details.
    """

    def __init__(self, document, table_row_path, index, load_encoding=None, password=None, encrypted_password=None):
        self.document = document
        self.table_row_path = table_row_path
        self.index = index
        self.load_encoding = load_encoding
        self.password = password
        self.encrypted_password = encrypted_password

    def create_http_request(self, api_client, encryptor):
        # verify the required parameter 'document' is set
        if self.document is None:
            raise ValueError("Missing the required parameter `document` when calling `get_table_cell_online`")  # noqa: E501
        # verify the required parameter 'table_row_path' is set
        if self.table_row_path is None:
            raise ValueError("Missing the required parameter `table_row_path` when calling `get_table_cell_online`")  # noqa: E501
        # verify the required parameter 'index' is set
        if self.index is None:
            raise ValueError("Missing the required parameter `index` when calling `get_table_cell_online`")  # noqa: E501

        path = '/v4.0/words/online/get/{tableRowPath}/cells/{index}'
        path_params = {}
        if self.table_row_path is not None:
            path_params['tableRowPath'] = self.table_row_path  # noqa: E501
        else:
            path_params['tableRowPath'] = ''  # noqa: E501
        if self.index is not None:
            path_params['index'] = self.index  # noqa: E501
        else:
            path_params['index'] = ''  # noqa: E501

        # path parameters
        collection_formats = {}
        if path_params:
            path_params = api_client.sanitize_for_serialization(path_params)
            path_params = api_client.parameters_to_tuples(path_params, collection_formats)
            for k, v in path_params:
                # specified safe chars, encode everything
                path = path.replace(
                    '{%s}' % k,
                    quote(str(v), safe=api_client.configuration.safe_chars_for_path_param)
                )

        # remove optional path parameters
        path = path.replace('//', '/')

        query_params = []
        if self.load_encoding is not None:
                query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
        if self.password is not None:
                query_params.append(('password', self.password))  # noqa: E501
        if self.encrypted_password is not None:
                query_params.append(('encryptedPassword', self.encrypted_password))  # noqa: E501

        header_params = {}
        # HTTP header `Content-Type`
        header_params['Content-Type'] = api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        file_content_params = []
        form_params = []
        if self.document is not None:
            form_params.append(['document', self.document, 'file'])  # noqa: E501

        for file_content_value in file_content_params:
            file_content_value.encryptPassword(encryptor)
            if file_content_value.source == 'Request':
                form_params.append([file_content_value.reference, file_content_value.content, 'file'])  # noqa: E501

        return {
            "method": "PUT",
            "path": path,
            "body": None,
            "query_params": query_params,
            "header_params": header_params,
            "form_params": form_params,
            "collection_formats": collection_formats,
            "response_type": 'TableCellResponse'  # noqa: E501
        }

    def get_response_type(self):
        return 'TableCellResponse'  # noqa: E501

    def deserialize_response(self, api_client, response):
        return api_client.deserialize(response.data, response.getheaders(), TableCellResponse)



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="csv_data_load_options.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class CsvDataLoadOptions(object):
    """Represents options for parsing CSV data. To learn more, visit the LINQ Reporting Engine documentation article. An instance of this class can be passed into constructors of CsvDataSource.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment_char': 'str',
        'delimiter': 'str',
        'has_headers': 'bool',
        'quote_char': 'str'
    }

    attribute_map = {
        'comment_char': 'CommentChar',
        'delimiter': 'Delimiter',
        'has_headers': 'HasHeaders',
        'quote_char': 'QuoteChar'
    }

    def __init__(self, comment_char=None, delimiter=None, has_headers=None, quote_char=None):  # noqa: E501
        """CsvDataLoadOptions - a model defined in Swagger"""  # noqa: E501

        self._comment_char = None
        self._delimiter = None
        self._has_headers = None
        self._quote_char = None
        self.discriminator = None

        if comment_char is not None:
            self.comment_char = comment_char
        if delimiter is not None:
            self.delimiter = delimiter
        if has_headers is not None:
            self.has_headers = has_headers
        if quote_char is not None:
            self.quote_char = quote_char

    @property
    def comment_char(self):
        """Gets the comment_char of this CsvDataLoadOptions.  # noqa: E501

        Gets or sets the character that is used to comment lines of CSV data. The default value is '#' (number sign).  # noqa: E501

        :return: The comment_char of this CsvDataLoadOptions.  # noqa: E501
        :rtype: str
        """
        return self._comment_char

    @comment_char.setter
    def comment_char(self, comment_char):
        """Sets the comment_char of this CsvDataLoadOptions.

        Gets or sets the character that is used to comment lines of CSV data. The default value is '#' (number sign).  # noqa: E501

        :param comment_char: The comment_char of this CsvDataLoadOptions.  # noqa: E501
        :type: str
        """
        self._comment_char = comment_char

    @property
    def delimiter(self):
        """Gets the delimiter of this CsvDataLoadOptions.  # noqa: E501

        Gets or sets the character to be used as a column delimiter. The default value is ',' (comma).  # noqa: E501

        :return: The delimiter of this CsvDataLoadOptions.  # noqa: E501
        :rtype: str
        """
        return self._delimiter

    @delimiter.setter
    def delimiter(self, delimiter):
        """Sets the delimiter of this CsvDataLoadOptions.

        Gets or sets the character to be used as a column delimiter. The default value is ',' (comma).  # noqa: E501

        :param delimiter: The delimiter of this CsvDataLoadOptions.  # noqa: E501
        :type: str
        """
        self._delimiter = delimiter

    @property
    def has_headers(self):
        """Gets the has_headers of this CsvDataLoadOptions.  # noqa: E501

        Gets or sets a value indicating whether the first record of CSV data contains column names. The default value is false.  # noqa: E501

        :return: The has_headers of this CsvDataLoadOptions.  # noqa: E501
        :rtype: bool
        """
        return self._has_headers

    @has_headers.setter
    def has_headers(self, has_headers):
        """Sets the has_headers of this CsvDataLoadOptions.

        Gets or sets a value indicating whether the first record of CSV data contains column names. The default value is false.  # noqa: E501

        :param has_headers: The has_headers of this CsvDataLoadOptions.  # noqa: E501
        :type: bool
        """
        self._has_headers = has_headers

    @property
    def quote_char(self):
        """Gets the quote_char of this CsvDataLoadOptions.  # noqa: E501

        Gets or sets the character that is used to quote field values. The default value is '"' (quotation mark).Double the character to place it into quoted text.  # noqa: E501

        :return: The quote_char of this CsvDataLoadOptions.  # noqa: E501
        :rtype: str
        """
        return self._quote_char

    @quote_char.setter
    def quote_char(self, quote_char):
        """Sets the quote_char of this CsvDataLoadOptions.

        Gets or sets the character that is used to quote field values. The default value is '"' (quotation mark).Double the character to place it into quoted text.  # noqa: E501

        :param quote_char: The quote_char of this CsvDataLoadOptions.  # noqa: E501
        :type: str
        """
        self._quote_char = quote_char


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""
        if self._comment_char is None:
            raise ValueError("Property CommentChar in CsvDataLoadOptions is required.")  # noqa: E501
        if self._delimiter is None:
            raise ValueError("Property Delimiter in CsvDataLoadOptions is required.")  # noqa: E501
        if self._has_headers is None:
            raise ValueError("Property HasHeaders in CsvDataLoadOptions is required.")  # noqa: E501
        if self._quote_char is None:
            raise ValueError("Property QuoteChar in CsvDataLoadOptions is required.")  # noqa: E501

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CsvDataLoadOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="compare_options.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class CompareOptions(object):
    """DTO container with compare documents options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'accept_all_revisions_before_comparison': 'bool',
        'ignore_case_changes': 'bool',
        'ignore_comments': 'bool',
        'ignore_fields': 'bool',
        'ignore_footnotes': 'bool',
        'ignore_formatting': 'bool',
        'ignore_headers_and_footers': 'bool',
        'ignore_tables': 'bool',
        'ignore_textboxes': 'bool',
        'target': 'str'
    }

    attribute_map = {
        'accept_all_revisions_before_comparison': 'AcceptAllRevisionsBeforeComparison',
        'ignore_case_changes': 'IgnoreCaseChanges',
        'ignore_comments': 'IgnoreComments',
        'ignore_fields': 'IgnoreFields',
        'ignore_footnotes': 'IgnoreFootnotes',
        'ignore_formatting': 'IgnoreFormatting',
        'ignore_headers_and_footers': 'IgnoreHeadersAndFooters',
        'ignore_tables': 'IgnoreTables',
        'ignore_textboxes': 'IgnoreTextboxes',
        'target': 'Target'
    }

    def __init__(self, accept_all_revisions_before_comparison=None, ignore_case_changes=None, ignore_comments=None, ignore_fields=None, ignore_footnotes=None, ignore_formatting=None, ignore_headers_and_footers=None, ignore_tables=None, ignore_textboxes=None, target=None):  # noqa: E501
        """CompareOptions - a model defined in Swagger"""  # noqa: E501

        self._accept_all_revisions_before_comparison = None
        self._ignore_case_changes = None
        self._ignore_comments = None
        self._ignore_fields = None
        self._ignore_footnotes = None
        self._ignore_formatting = None
        self._ignore_headers_and_footers = None
        self._ignore_tables = None
        self._ignore_textboxes = None
        self._target = None
        self.discriminator = None

        if accept_all_revisions_before_comparison is not None:
            self.accept_all_revisions_before_comparison = accept_all_revisions_before_comparison
        if ignore_case_changes is not None:
            self.ignore_case_changes = ignore_case_changes
        if ignore_comments is not None:
            self.ignore_comments = ignore_comments
        if ignore_fields is not None:
            self.ignore_fields = ignore_fields
        if ignore_footnotes is not None:
            self.ignore_footnotes = ignore_footnotes
        if ignore_formatting is not None:
            self.ignore_formatting = ignore_formatting
        if ignore_headers_and_footers is not None:
            self.ignore_headers_and_footers = ignore_headers_and_footers
        if ignore_tables is not None:
            self.ignore_tables = ignore_tables
        if ignore_textboxes is not None:
            self.ignore_textboxes = ignore_textboxes
        if target is not None:
            self.target = target

    @property
    def accept_all_revisions_before_comparison(self):
        """Gets the accept_all_revisions_before_comparison of this CompareOptions.  # noqa: E501

        Gets or sets whether accept revisions before comparison or not.  # noqa: E501

        :return: The accept_all_revisions_before_comparison of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._accept_all_revisions_before_comparison

    @accept_all_revisions_before_comparison.setter
    def accept_all_revisions_before_comparison(self, accept_all_revisions_before_comparison):
        """Sets the accept_all_revisions_before_comparison of this CompareOptions.

        Gets or sets whether accept revisions before comparison or not.  # noqa: E501

        :param accept_all_revisions_before_comparison: The accept_all_revisions_before_comparison of this CompareOptions.  # noqa: E501
        :type: bool
        """
        self._accept_all_revisions_before_comparison = accept_all_revisions_before_comparison

    @property
    def ignore_case_changes(self):
        """Gets the ignore_case_changes of this CompareOptions.  # noqa: E501

        Gets or sets a value indicating whether documents comparison is case insensitive. By default comparison is case sensitive.  # noqa: E501

        :return: The ignore_case_changes of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_case_changes

    @ignore_case_changes.setter
    def ignore_case_changes(self, ignore_case_changes):
        """Sets the ignore_case_changes of this CompareOptions.

        Gets or sets a value indicating whether documents comparison is case insensitive. By default comparison is case sensitive.  # noqa: E501

        :param ignore_case_changes: The ignore_case_changes of this CompareOptions.  # noqa: E501
        :type: bool
        """
        self._ignore_case_changes = ignore_case_changes

    @property
    def ignore_comments(self):
        """Gets the ignore_comments of this CompareOptions.  # noqa: E501

        Gets or sets a value indicating whether comments content is ignored. By default comments are not ignored.  # noqa: E501

        :return: The ignore_comments of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_comments

    @ignore_comments.setter
    def ignore_comments(self, ignore_comments):
        """Sets the ignore_comments of this CompareOptions.

        Gets or sets a value indicating whether comments content is ignored. By default comments are not ignored.  # noqa: E501

        :param ignore_comments: The ignore_comments of this CompareOptions.  # noqa: E501
        :type: bool
        """
        self._ignore_comments = ignore_comments

    @property
    def ignore_fields(self):
        """Gets the ignore_fields of this CompareOptions.  # noqa: E501

        Gets or sets a value indicating whether fields content is ignored. By default fields are not ignored.  # noqa: E501

        :return: The ignore_fields of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_fields

    @ignore_fields.setter
    def ignore_fields(self, ignore_fields):
        """Sets the ignore_fields of this CompareOptions.

        Gets or sets a value indicating whether fields content is ignored. By default fields are not ignored.  # noqa: E501

        :param ignore_fields: The ignore_fields of this CompareOptions.  # noqa: E501
        :type: bool
        """
        self._ignore_fields = ignore_fields

    @property
    def ignore_footnotes(self):
        """Gets the ignore_footnotes of this CompareOptions.  # noqa: E501

        Gets or sets a value indicating whether footnotes/endnotes content is ignored. By default footnotes/endnotes are not ignored.  # noqa: E501

        :return: The ignore_footnotes of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_footnotes

    @ignore_footnotes.setter
    def ignore_footnotes(self, ignore_footnotes):
        """Sets the ignore_footnotes of this CompareOptions.

        Gets or sets a value indicating whether footnotes/endnotes content is ignored. By default footnotes/endnotes are not ignored.  # noqa: E501

        :param ignore_footnotes: The ignore_footnotes of this CompareOptions.  # noqa: E501
        :type: bool
        """
        self._ignore_footnotes = ignore_footnotes

    @property
    def ignore_formatting(self):
        """Gets the ignore_formatting of this CompareOptions.  # noqa: E501

        Gets or sets a value indicating whether formatting is ignored. By default document formatting is not ignored.  # noqa: E501

        :return: The ignore_formatting of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_formatting

    @ignore_formatting.setter
    def ignore_formatting(self, ignore_formatting):
        """Sets the ignore_formatting of this CompareOptions.

        Gets or sets a value indicating whether formatting is ignored. By default document formatting is not ignored.  # noqa: E501

        :param ignore_formatting: The ignore_formatting of this CompareOptions.  # noqa: E501
        :type: bool
        """
        self._ignore_formatting = ignore_formatting

    @property
    def ignore_headers_and_footers(self):
        """Gets the ignore_headers_and_footers of this CompareOptions.  # noqa: E501

        Gets or sets a value indicating whether headers and footers content is ignored. By default headers and footers are not ignored.  # noqa: E501

        :return: The ignore_headers_and_footers of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_headers_and_footers

    @ignore_headers_and_footers.setter
    def ignore_headers_and_footers(self, ignore_headers_and_footers):
        """Sets the ignore_headers_and_footers of this CompareOptions.

        Gets or sets a value indicating whether headers and footers content is ignored. By default headers and footers are not ignored.  # noqa: E501

        :param ignore_headers_and_footers: The ignore_headers_and_footers of this CompareOptions.  # noqa: E501
        :type: bool
        """
        self._ignore_headers_and_footers = ignore_headers_and_footers

    @property
    def ignore_tables(self):
        """Gets the ignore_tables of this CompareOptions.  # noqa: E501

        Gets or sets a value indicating whether tables content is ignored. By default tables are not ignored.  # noqa: E501

        :return: The ignore_tables of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_tables

    @ignore_tables.setter
    def ignore_tables(self, ignore_tables):
        """Sets the ignore_tables of this CompareOptions.

        Gets or sets a value indicating whether tables content is ignored. By default tables are not ignored.  # noqa: E501

        :param ignore_tables: The ignore_tables of this CompareOptions.  # noqa: E501
        :type: bool
        """
        self._ignore_tables = ignore_tables

    @property
    def ignore_textboxes(self):
        """Gets the ignore_textboxes of this CompareOptions.  # noqa: E501

        Gets or sets a value indicating whether textboxes content is ignored. By default textboxes are not ignored.  # noqa: E501

        :return: The ignore_textboxes of this CompareOptions.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_textboxes

    @ignore_textboxes.setter
    def ignore_textboxes(self, ignore_textboxes):
        """Sets the ignore_textboxes of this CompareOptions.

        Gets or sets a value indicating whether textboxes content is ignored. By default textboxes are not ignored.  # noqa: E501

        :param ignore_textboxes: The ignore_textboxes of this CompareOptions.  # noqa: E501
        :type: bool
        """
        self._ignore_textboxes = ignore_textboxes

    @property
    def target(self):
        """Gets the target of this CompareOptions.  # noqa: E501

        Gets or sets the option that controls which document shall be used as a target during comparison.  # noqa: E501

        :return: The target of this CompareOptions.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this CompareOptions.

        Gets or sets the option that controls which document shall be used as a target during comparison.  # noqa: E501

        :param target: The target of this CompareOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["Current", "New"]  # noqa: E501
        if not target.isdigit():
            if target not in allowed_values:
                raise ValueError(
                    "Invalid value for `target` ({0}), must be one of {1}"  # noqa: E501
                    .format(target, allowed_values))
            self._target = target
        else:
            self._target = allowed_values[int(target) if six.PY3 else long(target)]


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompareOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="file_link.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class FileLink(object):
    """Provides information for the file link.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'href': 'str',
        'rel': 'str',
        'title': 'str',
        'type': 'str'
    }

    attribute_map = {
        'href': 'Href',
        'rel': 'Rel',
        'title': 'Title',
        'type': 'Type'
    }

    def __init__(self, href=None, rel=None, title=None, type=None):  # noqa: E501
        """FileLink - a model defined in Swagger"""  # noqa: E501

        self._href = None
        self._rel = None
        self._title = None
        self._type = None
        self.discriminator = None

        if href is not None:
            self.href = href
        if rel is not None:
            self.rel = rel
        if title is not None:
            self.title = title
        if type is not None:
            self.type = type

    @property
    def href(self):
        """Gets the href of this FileLink.  # noqa: E501

        Gets or sets the "href" attribute with the link's IRI. atom:link elements MUST have an href attribute, whose value MUST be a IRI reference.  # noqa: E501

        :return: The href of this FileLink.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this FileLink.

        Gets or sets the "href" attribute with the link's IRI. atom:link elements MUST have an href attribute, whose value MUST be a IRI reference.  # noqa: E501

        :param href: The href of this FileLink.  # noqa: E501
        :type: str
        """
        self._href = href

    @property
    def rel(self):
        """Gets the rel of this FileLink.  # noqa: E501

        Gets or sets the option that controls whether atom:link elements MAY have a "rel" attribute that indicates the link relation type.  If the "rel" attribute is not present, the link element MUST be interpreted as if the link relation type is "alternate".  # noqa: E501

        :return: The rel of this FileLink.  # noqa: E501
        :rtype: str
        """
        return self._rel

    @rel.setter
    def rel(self, rel):
        """Sets the rel of this FileLink.

        Gets or sets the option that controls whether atom:link elements MAY have a "rel" attribute that indicates the link relation type.  If the "rel" attribute is not present, the link element MUST be interpreted as if the link relation type is "alternate".  # noqa: E501

        :param rel: The rel of this FileLink.  # noqa: E501
        :type: str
        """
        self._rel = rel

    @property
    def title(self):
        """Gets the title of this FileLink.  # noqa: E501

        Gets or sets the "title" attribute, that conveys human-readable information about the link. The content of the "title" attribute is Language-Sensitive.  # noqa: E501

        :return: The title of this FileLink.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this FileLink.

        Gets or sets the "title" attribute, that conveys human-readable information about the link. The content of the "title" attribute is Language-Sensitive.  # noqa: E501

        :param title: The title of this FileLink.  # noqa: E501
        :type: str
        """
        self._title = title

    @property
    def type(self):
        """Gets the type of this FileLink.  # noqa: E501

        Gets or sets the "type" attribute. The "type" attribute's value is an advisory media type: it is a hint about the type of the representation that is expected to be returned when the value of the href attribute is dereferenced. Note that the type attribute does not override the actual media type returned with the representation.  # noqa: E501

        :return: The type of this FileLink.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FileLink.

        Gets or sets the "type" attribute. The "type" attribute's value is an advisory media type: it is a hint about the type of the representation that is expected to be returned when the value of the href attribute is dereferenced. Note that the type attribute does not override the actual media type returned with the representation.  # noqa: E501

        :param type: The type of this FileLink.  # noqa: E501
        :type: str
        """
        self._type = type


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileLink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="list_info.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class ListInfo(object):
    """DTO container with a single document list.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'list_id': 'int',
        'is_multi_level': 'bool',
        'is_restart_at_each_section': 'bool',
        'is_list_style_definition': 'bool',
        'is_list_style_reference': 'bool',
        'style': 'Style',
        'list_levels': 'ListLevels'
    }

    attribute_map = {
        'link': 'Link',
        'list_id': 'ListId',
        'is_multi_level': 'IsMultiLevel',
        'is_restart_at_each_section': 'IsRestartAtEachSection',
        'is_list_style_definition': 'IsListStyleDefinition',
        'is_list_style_reference': 'IsListStyleReference',
        'style': 'Style',
        'list_levels': 'ListLevels'
    }

    def __init__(self, link=None, list_id=None, is_multi_level=None, is_restart_at_each_section=None, is_list_style_definition=None, is_list_style_reference=None, style=None, list_levels=None):  # noqa: E501
        """ListInfo - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._list_id = None
        self._is_multi_level = None
        self._is_restart_at_each_section = None
        self._is_list_style_definition = None
        self._is_list_style_reference = None
        self._style = None
        self._list_levels = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if list_id is not None:
            self.list_id = list_id
        if is_multi_level is not None:
            self.is_multi_level = is_multi_level
        if is_restart_at_each_section is not None:
            self.is_restart_at_each_section = is_restart_at_each_section
        if is_list_style_definition is not None:
            self.is_list_style_definition = is_list_style_definition
        if is_list_style_reference is not None:
            self.is_list_style_reference = is_list_style_reference
        if style is not None:
            self.style = style
        if list_levels is not None:
            self.list_levels = list_levels

    @property
    def link(self):
        """Gets the link of this ListInfo.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this ListInfo.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this ListInfo.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this ListInfo.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def list_id(self):
        """Gets the list_id of this ListInfo.  # noqa: E501

        Gets or sets the unique identifier of the list. You do not normally need to use this property. But if you use it, you normally do so in conjunction with the Aspose.Words.Lists.ListCollection.GetListByListId(System.Int32) method to find a list by its identifier.  # noqa: E501

        :return: The list_id of this ListInfo.  # noqa: E501
        :rtype: int
        """
        return self._list_id

    @list_id.setter
    def list_id(self, list_id):
        """Sets the list_id of this ListInfo.

        Gets or sets the unique identifier of the list. You do not normally need to use this property. But if you use it, you normally do so in conjunction with the Aspose.Words.Lists.ListCollection.GetListByListId(System.Int32) method to find a list by its identifier.  # noqa: E501

        :param list_id: The list_id of this ListInfo.  # noqa: E501
        :type: int
        """
        self._list_id = list_id

    @property
    def is_multi_level(self):
        """Gets the is_multi_level of this ListInfo.  # noqa: E501

        Gets or sets a value indicating whether the list contains 9 levels; false when 1 level. The lists that you create with Aspose.Words are always multi-level lists and contain 9 levels. Microsoft Word 2003 and later always create multi-level lists with 9 levels. But in some documents, created with earlier versions of Microsoft Word you might encounter lists that have 1 level only.  # noqa: E501

        :return: The is_multi_level of this ListInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_multi_level

    @is_multi_level.setter
    def is_multi_level(self, is_multi_level):
        """Sets the is_multi_level of this ListInfo.

        Gets or sets a value indicating whether the list contains 9 levels; false when 1 level. The lists that you create with Aspose.Words are always multi-level lists and contain 9 levels. Microsoft Word 2003 and later always create multi-level lists with 9 levels. But in some documents, created with earlier versions of Microsoft Word you might encounter lists that have 1 level only.  # noqa: E501

        :param is_multi_level: The is_multi_level of this ListInfo.  # noqa: E501
        :type: bool
        """
        self._is_multi_level = is_multi_level

    @property
    def is_restart_at_each_section(self):
        """Gets the is_restart_at_each_section of this ListInfo.  # noqa: E501

        Gets or sets a value indicating whether list should be restarted at each section. The default value is false. This option is supported only in RTF, DOC and DOCX document formats. This option will be written to DOCX only if Aspose.Words.Saving.OoxmlCompliance is higher then Aspose.Words.Saving.OoxmlCompliance.Ecma376_2006.  # noqa: E501

        :return: The is_restart_at_each_section of this ListInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_restart_at_each_section

    @is_restart_at_each_section.setter
    def is_restart_at_each_section(self, is_restart_at_each_section):
        """Sets the is_restart_at_each_section of this ListInfo.

        Gets or sets a value indicating whether list should be restarted at each section. The default value is false. This option is supported only in RTF, DOC and DOCX document formats. This option will be written to DOCX only if Aspose.Words.Saving.OoxmlCompliance is higher then Aspose.Words.Saving.OoxmlCompliance.Ecma376_2006.  # noqa: E501

        :param is_restart_at_each_section: The is_restart_at_each_section of this ListInfo.  # noqa: E501
        :type: bool
        """
        self._is_restart_at_each_section = is_restart_at_each_section

    @property
    def is_list_style_definition(self):
        """Gets the is_list_style_definition of this ListInfo.  # noqa: E501

        Gets or sets a value indicating whether this list is a definition of a list style. When this property is true, the Aspose.Words.Lists.List.Style property returns the list style that this list defines. By modifying properties of a list that defines a list style, you modify The properties of the list style. A list that is a definition of a list style cannot be applied directly to paragraphs to make them numbered. Aspose.Words.Lists.List.Style Aspose.Words.Lists.List.IsListStyleReference.  # noqa: E501

        :return: The is_list_style_definition of this ListInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_list_style_definition

    @is_list_style_definition.setter
    def is_list_style_definition(self, is_list_style_definition):
        """Sets the is_list_style_definition of this ListInfo.

        Gets or sets a value indicating whether this list is a definition of a list style. When this property is true, the Aspose.Words.Lists.List.Style property returns the list style that this list defines. By modifying properties of a list that defines a list style, you modify The properties of the list style. A list that is a definition of a list style cannot be applied directly to paragraphs to make them numbered. Aspose.Words.Lists.List.Style Aspose.Words.Lists.List.IsListStyleReference.  # noqa: E501

        :param is_list_style_definition: The is_list_style_definition of this ListInfo.  # noqa: E501
        :type: bool
        """
        self._is_list_style_definition = is_list_style_definition

    @property
    def is_list_style_reference(self):
        """Gets the is_list_style_reference of this ListInfo.  # noqa: E501

        Gets or sets a value indicating whether this list is a reference to a list style. Note, modifying properties of a list that is a reference to list style has no effect. The list formatting specified in the list style itself always takes precedence. Aspose.Words.Lists.List.Style Aspose.Words.Lists.List.IsListStyleDefinition.  # noqa: E501

        :return: The is_list_style_reference of this ListInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_list_style_reference

    @is_list_style_reference.setter
    def is_list_style_reference(self, is_list_style_reference):
        """Sets the is_list_style_reference of this ListInfo.

        Gets or sets a value indicating whether this list is a reference to a list style. Note, modifying properties of a list that is a reference to list style has no effect. The list formatting specified in the list style itself always takes precedence. Aspose.Words.Lists.List.Style Aspose.Words.Lists.List.IsListStyleDefinition.  # noqa: E501

        :param is_list_style_reference: The is_list_style_reference of this ListInfo.  # noqa: E501
        :type: bool
        """
        self._is_list_style_reference = is_list_style_reference

    @property
    def style(self):
        """Gets the style of this ListInfo.  # noqa: E501

        Gets or sets the list style that this list references or defines. If this list is not associated with a list style, the property will return null. A list could be a reference to a list style, in this case Aspose.Words.Lists.List.IsListStyleReference will be true. A list could be a definition of a list style, in this case Aspose.Words.Lists.List.IsListStyleDefinition will be true. Such a list cannot be applied to paragraphs in the document directly.  # noqa: E501

        :return: The style of this ListInfo.  # noqa: E501
        :rtype: Style
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this ListInfo.

        Gets or sets the list style that this list references or defines. If this list is not associated with a list style, the property will return null. A list could be a reference to a list style, in this case Aspose.Words.Lists.List.IsListStyleReference will be true. A list could be a definition of a list style, in this case Aspose.Words.Lists.List.IsListStyleDefinition will be true. Such a list cannot be applied to paragraphs in the document directly.  # noqa: E501

        :param style: The style of this ListInfo.  # noqa: E501
        :type: Style
        """
        self._style = style

    @property
    def list_levels(self):
        """Gets the list_levels of this ListInfo.  # noqa: E501

        Gets or sets the collection of list levels for this list. Use this property to access and modify formatting individual to each level of the list.  # noqa: E501

        :return: The list_levels of this ListInfo.  # noqa: E501
        :rtype: ListLevels
        """
        return self._list_levels

    @list_levels.setter
    def list_levels(self, list_levels):
        """Sets the list_levels of this ListInfo.

        Gets or sets the collection of list levels for this list. Use this property to access and modify formatting individual to each level of the list.  # noqa: E501

        :param list_levels: The list_levels of this ListInfo.  # noqa: E501
        :type: ListLevels
        """
        self._list_levels = list_levels


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""
        if self._list_id is None:
            raise ValueError("Property ListId in ListInfo is required.")  # noqa: E501
        if self._is_multi_level is None:
            raise ValueError("Property IsMultiLevel in ListInfo is required.")  # noqa: E501
        if self._is_restart_at_each_section is None:
            raise ValueError("Property IsRestartAtEachSection in ListInfo is required.")  # noqa: E501
        if self._is_list_style_definition is None:
            raise ValueError("Property IsListStyleDefinition in ListInfo is required.")  # noqa: E501
        if self._is_list_style_reference is None:
            raise ValueError("Property IsListStyleReference in ListInfo is required.")  # noqa: E501

        if self._link is not None:
            self._link.validate()








        if self._style is not None:
            self._style.validate()



        if self._list_levels is not None:
            self._list_levels.validate()


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


import uuid
import io

class BatchRequest(object):
    """
    Request wrapper for batch operation.
    Initializes a new instance.
    :param request The request to wrap.
    """
    def __init__(self, request):
        self.request = request
        self.id = str(uuid.uuid4())
        self.parent_id = None 

    def depends_on(self, parent_request):
        self.parent_id = parent_request.id

    def create_http_request(self, api_client, encryptor):
        http_request = self.request.create_http_request(api_client, encryptor)
        http_request["header_params"]["RequestId"] = self.id

        if self.parent_id is not None:
            http_request["header_params"]["DependsOn"] = self.parent_id

        return http_request

    def get_response_type(self):
        return self.request.get_response_type()

    def deserialize_response(self, api_client, response):
        return self.request.deserialize_response(api_client, response)

    def use_as_source(self):
        data = io.StringIO()
        data.write('resultOf(' + self.id + ')')
        return data



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="table_cell_format.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class TableCellFormat(object):
    """DTO container with all formatting for a table row.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'bottom_padding': 'float',
        'fit_text': 'bool',
        'horizontal_merge': 'str',
        'left_padding': 'float',
        'orientation': 'str',
        'preferred_width': 'PreferredWidth',
        'right_padding': 'float',
        'top_padding': 'float',
        'vertical_alignment': 'str',
        'vertical_merge': 'str',
        'width': 'float',
        'wrap_text': 'bool'
    }

    attribute_map = {
        'link': 'Link',
        'bottom_padding': 'BottomPadding',
        'fit_text': 'FitText',
        'horizontal_merge': 'HorizontalMerge',
        'left_padding': 'LeftPadding',
        'orientation': 'Orientation',
        'preferred_width': 'PreferredWidth',
        'right_padding': 'RightPadding',
        'top_padding': 'TopPadding',
        'vertical_alignment': 'VerticalAlignment',
        'vertical_merge': 'VerticalMerge',
        'width': 'Width',
        'wrap_text': 'WrapText'
    }

    def __init__(self, link=None, bottom_padding=None, fit_text=None, horizontal_merge=None, left_padding=None, orientation=None, preferred_width=None, right_padding=None, top_padding=None, vertical_alignment=None, vertical_merge=None, width=None, wrap_text=None):  # noqa: E501
        """TableCellFormat - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._bottom_padding = None
        self._fit_text = None
        self._horizontal_merge = None
        self._left_padding = None
        self._orientation = None
        self._preferred_width = None
        self._right_padding = None
        self._top_padding = None
        self._vertical_alignment = None
        self._vertical_merge = None
        self._width = None
        self._wrap_text = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if bottom_padding is not None:
            self.bottom_padding = bottom_padding
        if fit_text is not None:
            self.fit_text = fit_text
        if horizontal_merge is not None:
            self.horizontal_merge = horizontal_merge
        if left_padding is not None:
            self.left_padding = left_padding
        if orientation is not None:
            self.orientation = orientation
        if preferred_width is not None:
            self.preferred_width = preferred_width
        if right_padding is not None:
            self.right_padding = right_padding
        if top_padding is not None:
            self.top_padding = top_padding
        if vertical_alignment is not None:
            self.vertical_alignment = vertical_alignment
        if vertical_merge is not None:
            self.vertical_merge = vertical_merge
        if width is not None:
            self.width = width
        if wrap_text is not None:
            self.wrap_text = wrap_text

    @property
    def link(self):
        """Gets the link of this TableCellFormat.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this TableCellFormat.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this TableCellFormat.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this TableCellFormat.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def bottom_padding(self):
        """Gets the bottom_padding of this TableCellFormat.  # noqa: E501

        Gets or sets the amount of space (in points) to add below the contents of the cell.  # noqa: E501

        :return: The bottom_padding of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._bottom_padding

    @bottom_padding.setter
    def bottom_padding(self, bottom_padding):
        """Sets the bottom_padding of this TableCellFormat.

        Gets or sets the amount of space (in points) to add below the contents of the cell.  # noqa: E501

        :param bottom_padding: The bottom_padding of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._bottom_padding = bottom_padding

    @property
    def fit_text(self):
        """Gets the fit_text of this TableCellFormat.  # noqa: E501

        Gets or sets a value indicating whether to fit text in the cell, compress each paragraph to the width of the cell.  # noqa: E501

        :return: The fit_text of this TableCellFormat.  # noqa: E501
        :rtype: bool
        """
        return self._fit_text

    @fit_text.setter
    def fit_text(self, fit_text):
        """Sets the fit_text of this TableCellFormat.

        Gets or sets a value indicating whether to fit text in the cell, compress each paragraph to the width of the cell.  # noqa: E501

        :param fit_text: The fit_text of this TableCellFormat.  # noqa: E501
        :type: bool
        """
        self._fit_text = fit_text

    @property
    def horizontal_merge(self):
        """Gets the horizontal_merge of this TableCellFormat.  # noqa: E501

        Gets or sets the option that controls how the cell is merged horizontally with other cells in the row.  # noqa: E501

        :return: The horizontal_merge of this TableCellFormat.  # noqa: E501
        :rtype: str
        """
        return self._horizontal_merge

    @horizontal_merge.setter
    def horizontal_merge(self, horizontal_merge):
        """Sets the horizontal_merge of this TableCellFormat.

        Gets or sets the option that controls how the cell is merged horizontally with other cells in the row.  # noqa: E501

        :param horizontal_merge: The horizontal_merge of this TableCellFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "First", "Previous"]  # noqa: E501
        if not horizontal_merge.isdigit():
            if horizontal_merge not in allowed_values:
                raise ValueError(
                    "Invalid value for `horizontal_merge` ({0}), must be one of {1}"  # noqa: E501
                    .format(horizontal_merge, allowed_values))
            self._horizontal_merge = horizontal_merge
        else:
            self._horizontal_merge = allowed_values[int(horizontal_merge) if six.PY3 else long(horizontal_merge)]

    @property
    def left_padding(self):
        """Gets the left_padding of this TableCellFormat.  # noqa: E501

        Gets or sets the amount of space (in points) to add to the left of the contents of the cell.  # noqa: E501

        :return: The left_padding of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._left_padding

    @left_padding.setter
    def left_padding(self, left_padding):
        """Sets the left_padding of this TableCellFormat.

        Gets or sets the amount of space (in points) to add to the left of the contents of the cell.  # noqa: E501

        :param left_padding: The left_padding of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._left_padding = left_padding

    @property
    def orientation(self):
        """Gets the orientation of this TableCellFormat.  # noqa: E501

        Gets or sets the orientation of text in a table cell.  # noqa: E501

        :return: The orientation of this TableCellFormat.  # noqa: E501
        :rtype: str
        """
        return self._orientation

    @orientation.setter
    def orientation(self, orientation):
        """Sets the orientation of this TableCellFormat.

        Gets or sets the orientation of text in a table cell.  # noqa: E501

        :param orientation: The orientation of this TableCellFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["Horizontal", "Downward", "Upward", "HorizontalRotatedFarEast", "VerticalFarEast", "VerticalRotatedFarEast"]  # noqa: E501
        if not orientation.isdigit():
            if orientation not in allowed_values:
                raise ValueError(
                    "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
                    .format(orientation, allowed_values))
            self._orientation = orientation
        else:
            self._orientation = allowed_values[int(orientation) if six.PY3 else long(orientation)]

    @property
    def preferred_width(self):
        """Gets the preferred_width of this TableCellFormat.  # noqa: E501

        Gets or sets the preferred width of the cell. The preferred width (along with the table's Auto Fit option) determines how the actual width of the cell is calculated by the table layout algorithm. Table layout can be performed by Aspose.Words when it saves the document or by Microsoft Word when it displays the document.The preferred width can be specified in points or in percent. The preferred width can also be specified as "auto", which means no preferred width is specified.The default value is Auto.  # noqa: E501

        :return: The preferred_width of this TableCellFormat.  # noqa: E501
        :rtype: PreferredWidth
        """
        return self._preferred_width

    @preferred_width.setter
    def preferred_width(self, preferred_width):
        """Sets the preferred_width of this TableCellFormat.

        Gets or sets the preferred width of the cell. The preferred width (along with the table's Auto Fit option) determines how the actual width of the cell is calculated by the table layout algorithm. Table layout can be performed by Aspose.Words when it saves the document or by Microsoft Word when it displays the document.The preferred width can be specified in points or in percent. The preferred width can also be specified as "auto", which means no preferred width is specified.The default value is Auto.  # noqa: E501

        :param preferred_width: The preferred_width of this TableCellFormat.  # noqa: E501
        :type: PreferredWidth
        """
        self._preferred_width = preferred_width

    @property
    def right_padding(self):
        """Gets the right_padding of this TableCellFormat.  # noqa: E501

        Gets or sets the amount of space (in points) to add to the right of the contents of the cell.  # noqa: E501

        :return: The right_padding of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._right_padding

    @right_padding.setter
    def right_padding(self, right_padding):
        """Sets the right_padding of this TableCellFormat.

        Gets or sets the amount of space (in points) to add to the right of the contents of the cell.  # noqa: E501

        :param right_padding: The right_padding of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._right_padding = right_padding

    @property
    def top_padding(self):
        """Gets the top_padding of this TableCellFormat.  # noqa: E501

        Gets or sets the amount of space (in points) to add above the contents of the cell.  # noqa: E501

        :return: The top_padding of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._top_padding

    @top_padding.setter
    def top_padding(self, top_padding):
        """Sets the top_padding of this TableCellFormat.

        Gets or sets the amount of space (in points) to add above the contents of the cell.  # noqa: E501

        :param top_padding: The top_padding of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._top_padding = top_padding

    @property
    def vertical_alignment(self):
        """Gets the vertical_alignment of this TableCellFormat.  # noqa: E501

        Gets or sets the vertical alignment of text in the cell.  # noqa: E501

        :return: The vertical_alignment of this TableCellFormat.  # noqa: E501
        :rtype: str
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """Sets the vertical_alignment of this TableCellFormat.

        Gets or sets the vertical alignment of text in the cell.  # noqa: E501

        :param vertical_alignment: The vertical_alignment of this TableCellFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["Top", "Center", "Bottom"]  # noqa: E501
        if not vertical_alignment.isdigit():
            if vertical_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_alignment, allowed_values))
            self._vertical_alignment = vertical_alignment
        else:
            self._vertical_alignment = allowed_values[int(vertical_alignment) if six.PY3 else long(vertical_alignment)]

    @property
    def vertical_merge(self):
        """Gets the vertical_merge of this TableCellFormat.  # noqa: E501

        Gets or sets the option that controls how the cell is merged with other cells vertically. Cells can only be merged vertically if their left and right boundaries are identical.When cells are vertically merged, the display areas of the merged cells are consolidated. The consolidated area is used to display the contents of the first vertically merged cell and all other vertically merged cells must be empty.  # noqa: E501

        :return: The vertical_merge of this TableCellFormat.  # noqa: E501
        :rtype: str
        """
        return self._vertical_merge

    @vertical_merge.setter
    def vertical_merge(self, vertical_merge):
        """Sets the vertical_merge of this TableCellFormat.

        Gets or sets the option that controls how the cell is merged with other cells vertically. Cells can only be merged vertically if their left and right boundaries are identical.When cells are vertically merged, the display areas of the merged cells are consolidated. The consolidated area is used to display the contents of the first vertically merged cell and all other vertically merged cells must be empty.  # noqa: E501

        :param vertical_merge: The vertical_merge of this TableCellFormat.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "First", "Previous"]  # noqa: E501
        if not vertical_merge.isdigit():
            if vertical_merge not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_merge` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_merge, allowed_values))
            self._vertical_merge = vertical_merge
        else:
            self._vertical_merge = allowed_values[int(vertical_merge) if six.PY3 else long(vertical_merge)]

    @property
    def width(self):
        """Gets the width of this TableCellFormat.  # noqa: E501

        Gets or sets the width of the cell in points. The width is calculated by Aspose.Words on document loading and saving. Currently, not every combination of table, cell and document properties is supported. The returned value may not be accurate for some documents. It may not exactly match the cell width as calculated by MS Word when the document is opened in MS Word.Setting this property is not recommended. There is no guarantee that the cell will actually have the set width. The width may be adjusted to accommodate cell contents in an auto-fit table layout. Cells in other rows may have conflicting width settings. The table may be resized to fit into the container or to meet table width settings. Consider using PreferredWidth for setting the cell width. Setting this property sets PreferredWidth implicitly since version 15.8.  # noqa: E501

        :return: The width of this TableCellFormat.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this TableCellFormat.

        Gets or sets the width of the cell in points. The width is calculated by Aspose.Words on document loading and saving. Currently, not every combination of table, cell and document properties is supported. The returned value may not be accurate for some documents. It may not exactly match the cell width as calculated by MS Word when the document is opened in MS Word.Setting this property is not recommended. There is no guarantee that the cell will actually have the set width. The width may be adjusted to accommodate cell contents in an auto-fit table layout. Cells in other rows may have conflicting width settings. The table may be resized to fit into the container or to meet table width settings. Consider using PreferredWidth for setting the cell width. Setting this property sets PreferredWidth implicitly since version 15.8.  # noqa: E501

        :param width: The width of this TableCellFormat.  # noqa: E501
        :type: float
        """
        self._width = width

    @property
    def wrap_text(self):
        """Gets the wrap_text of this TableCellFormat.  # noqa: E501

        Gets or sets a value indicating whether to wrap text in the cell.  # noqa: E501

        :return: The wrap_text of this TableCellFormat.  # noqa: E501
        :rtype: bool
        """
        return self._wrap_text

    @wrap_text.setter
    def wrap_text(self, wrap_text):
        """Sets the wrap_text of this TableCellFormat.

        Gets or sets a value indicating whether to wrap text in the cell.  # noqa: E501

        :param wrap_text: The wrap_text of this TableCellFormat.  # noqa: E501
        :type: bool
        """
        self._wrap_text = wrap_text


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

        if self._link is not None:
            self._link.validate()








        if self._preferred_width is not None:
            self._preferred_width.validate()








    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TableCellFormat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="compress_options.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class CompressOptions(object):
    """Options of document compress.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'images_quality': 'int',
        'images_reduce_size_factor': 'int'
    }

    attribute_map = {
        'images_quality': 'ImagesQuality',
        'images_reduce_size_factor': 'ImagesReduceSizeFactor'
    }

    def __init__(self, images_quality=None, images_reduce_size_factor=None):  # noqa: E501
        """CompressOptions - a model defined in Swagger"""  # noqa: E501

        self._images_quality = None
        self._images_reduce_size_factor = None
        self.discriminator = None

        if images_quality is not None:
            self.images_quality = images_quality
        if images_reduce_size_factor is not None:
            self.images_reduce_size_factor = images_reduce_size_factor

    @property
    def images_quality(self):
        """Gets the images_quality of this CompressOptions.  # noqa: E501

        Gets or sets the quality level of images from 0 to 100. Default value is 75.  # noqa: E501

        :return: The images_quality of this CompressOptions.  # noqa: E501
        :rtype: int
        """
        return self._images_quality

    @images_quality.setter
    def images_quality(self, images_quality):
        """Sets the images_quality of this CompressOptions.

        Gets or sets the quality level of images from 0 to 100. Default value is 75.  # noqa: E501

        :param images_quality: The images_quality of this CompressOptions.  # noqa: E501
        :type: int
        """
        self._images_quality = images_quality

    @property
    def images_reduce_size_factor(self):
        """Gets the images_reduce_size_factor of this CompressOptions.  # noqa: E501

        Gets or sets the resize factor of images. This value determines how many times the size of the images in the document will be reduced. The parameter value must be greater than 1 for resizing. Default value is 1 and has no effect on images size.  # noqa: E501

        :return: The images_reduce_size_factor of this CompressOptions.  # noqa: E501
        :rtype: int
        """
        return self._images_reduce_size_factor

    @images_reduce_size_factor.setter
    def images_reduce_size_factor(self, images_reduce_size_factor):
        """Sets the images_reduce_size_factor of this CompressOptions.

        Gets or sets the resize factor of images. This value determines how many times the size of the images in the document will be reduced. The parameter value must be greater than 1 for resizing. Default value is 1 and has no effect on images size.  # noqa: E501

        :param images_reduce_size_factor: The images_reduce_size_factor of this CompressOptions.  # noqa: E501
        :type: int
        """
        self._images_reduce_size_factor = images_reduce_size_factor


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompressOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="watermark_data_text.py">
#   Copyright (c) 2024 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class WatermarkDataText(object):
    """Class for insert watermark text request building.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'color': 'XmlColor',
        'font_family': 'str',
        'font_size': 'float',
        'is_semitrasparent': 'bool',
        'layout': 'str',
        'text': 'str'
    }

    attribute_map = {
        'color': 'Color',
        'font_family': 'FontFamily',
        'font_size': 'FontSize',
        'is_semitrasparent': 'IsSemitrasparent',
        'layout': 'Layout',
        'text': 'Text'
    }

    def __init__(self, color=None, font_family=None, font_size=None, is_semitrasparent=None, layout=None, text=None):  # noqa: E501
        """WatermarkDataText - a model defined in Swagger"""  # noqa: E501

        self._color = None
        self._font_family = None
        self._font_size = None
        self._is_semitrasparent = None
        self._layout = None
        self._text = None
        self.discriminator = None

        if color is not None:
            self.color = color
        if font_family is not None:
            self.font_family = font_family
        if font_size is not None:
            self.font_size = font_size
        if is_semitrasparent is not None:
            self.is_semitrasparent = is_semitrasparent
        if layout is not None:
            self.layout = layout
        if text is not None:
            self.text = text

    @property
    def color(self):
        """Gets the color of this WatermarkDataText.  # noqa: E501

        Gets or sets font color. The default value is System.Drawing.Color.Silver.  # noqa: E501

        :return: The color of this WatermarkDataText.  # noqa: E501
        :rtype: XmlColor
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this WatermarkDataText.

        Gets or sets font color. The default value is System.Drawing.Color.Silver.  # noqa: E501

        :param color: The color of this WatermarkDataText.  # noqa: E501
        :type: XmlColor
        """
        self._color = color

    @property
    def font_family(self):
        """Gets the font_family of this WatermarkDataText.  # noqa: E501

        Gets or sets font family name. The default value is "Calibri".  # noqa: E501

        :return: The font_family of this WatermarkDataText.  # noqa: E501
        :rtype: str
        """
        return self._font_family

    @font_family.setter
    def font_family(self, font_family):
        """Sets the font_family of this WatermarkDataText.

        Gets or sets font family name. The default value is "Calibri".  # noqa: E501

        :param font_family: The font_family of this WatermarkDataText.  # noqa: E501
        :type: str
        """
        self._font_family = font_family

    @property
    def font_size(self):
        """Gets the font_size of this WatermarkDataText.  # noqa: E501

        Gets or sets a font size. The default value is 0 - auto. Valid values range from 0 to 65.5 inclusive. Auto font size means that the watermark will be scaled to its max width and max height relative to the page margins.  # noqa: E501

        :return: The font_size of this WatermarkDataText.  # noqa: E501
        :rtype: float
        """
        return self._font_size

    @font_size.setter
    def font_size(self, font_size):
        """Sets the font_size of this WatermarkDataText.

        Gets or sets a font size. The default value is 0 - auto. Valid values range from 0 to 65.5 inclusive. Auto font size means that the watermark will be scaled to its max width and max height relative to the page margins.  # noqa: E501

        :param font_size: The font_size of this WatermarkDataText.  # noqa: E501
        :type: float
        """
        self._font_size = font_size

    @property
    def is_semitrasparent(self):
        """Gets the is_semitrasparent of this WatermarkDataText.  # noqa: E501

        Gets or sets a boolean value which is responsible for opacity of the watermark. The default value is true.  # noqa: E501

        :return: The is_semitrasparent of this WatermarkDataText.  # noqa: E501
        :rtype: bool
        """
        return self._is_semitrasparent

    @is_semitrasparent.setter
    def is_semitrasparent(self, is_semitrasparent):
        """Sets the is_semitrasparent of this WatermarkDataText.

        Gets or sets a boolean value which is responsible for opacity of the watermark. The default value is true.  # noqa: E501

        :param is_semitrasparent: The is_semitrasparent of this WatermarkDataText.  # noqa: E501
        :type: bool
        """
        self._is_semitrasparent = is_semitrasparent

    @property
    def layout(self):
        """Gets the layout of this WatermarkDataText.  # noqa: E501

        Gets or sets layout of the watermark. The default value is Aspose.Words.WatermarkLayout.Diagonal.  # noqa: E501

        :return: The layout of this WatermarkDataText.  # noqa: E501
        :rtype: str
        """
        return self._layout

    @layout.setter
    def layout(self, layout):
        """Sets the layout of this WatermarkDataText.

        Gets or sets layout of the watermark. The default value is Aspose.Words.WatermarkLayout.Diagonal.  # noqa: E501

        :param layout: The layout of this WatermarkDataText.  # noqa: E501
        :type: str
        """
        allowed_values = ["Horizontal", "Diagonal"]  # noqa: E501
        if not layout.isdigit():
            if layout not in allowed_values:
                raise ValueError(
                    "Invalid value for `layout` ({0}), must be one of {1}"  # noqa: E501
                    .format(layout, allowed_values))
            self._layout = layout
        else:
            self._layout = allowed_values[int(layout) if six.PY3 else long(layout)]

    @property
    def text(self):
        """Gets the text of this WatermarkDataText.  # noqa: E501

        Gets or sets the watermark text.  # noqa: E501

        :return: The text of this WatermarkDataText.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this WatermarkDataText.

        Gets or sets the watermark text.  # noqa: E501

        :param text: The text of this WatermarkDataText.  # noqa: E501
        :type: str
        """
        self._text = text


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def validate(self):
        """Validate all required properties in model"""
        if self._text is None:
            raise ValueError("Property Text in WatermarkDataText is required.")  # noqa: E501

        if self._color is not None:
            self._color.validate()







    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WatermarkDataText):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other